@@ -1,11 +1,12 @@
 import { render, screen } from '@testing-library/react';
-import React from 'react';
 
+import { BootData } from '@grafana/data';
 import { setEchoSrv } from '@grafana/runtime/src';
 import config from 'app/core/config';
 
 import { Echo } from '../../../../core/services/echo/Echo';
-import { DashboardModel, PanelModel } from '../../state';
+import { PanelModel } from '../../state';
+import { createDashboardModelFixture } from '../../state/__fixtures__/dashboardFixtures';
 
 import { ShareEmbed } from './ShareEmbed';
 
@@ -39,7 +40,7 @@ function mockLocationHref(href: string) {
 
   // @ts-ignore
   delete window.location;
-  (window as any).location = {
+  window.location = {
     ...location,
     href,
     origin: new URL(href).origin,
@@ -48,7 +49,7 @@ function mockLocationHref(href: string) {
 }
 
 describe('ShareEmbed', () => {
-  let originalBootData: any;
+  let originalBootData: BootData;
 
   beforeAll(() => {
     setEchoSrv(new Echo());
@@ -59,7 +60,7 @@ describe('ShareEmbed', () => {
       user: {
         orgId: 1,
       },
-    } as any;
+    } as BootData;
   });
 
   afterAll(() => {
@@ -67,7 +68,7 @@ describe('ShareEmbed', () => {
   });
 
   it('generates the correct embed url for a dashboard', () => {
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
@@ -85,7 +86,7 @@ describe('ShareEmbed', () => {
 
   it('generates the correct embed url for a dashboard set to the homepage in the grafana config', () => {
     mockLocationHref('http://dashboards.grafana.com/?orgId=1');
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
@@ -103,7 +104,7 @@ describe('ShareEmbed', () => {
   it('generates the correct embed url for a snapshot', () => {
     const mockSlug = 'mockSlug';
     mockLocationHref(`http://dashboards.grafana.com/dashboard/snapshot/${mockSlug}?orgId=1`);
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
@@ -121,7 +122,7 @@ describe('ShareEmbed', () => {
   it('generates the correct embed url for a scripted dashboard', () => {
     const mockSlug = 'scripted.js';
     mockLocationHref(`http://dashboards.grafana.com/dashboard/script/${mockSlug}?orgId=1`);
-    const mockDashboard = new DashboardModel({
+    const mockDashboard = createDashboardModelFixture({
       uid: 'mockDashboardUid',
     });
     const mockPanel = new PanelModel({
